import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:vnoteapp/components/appbar.dart';
import 'package:vnoteapp/components/cell.dart';
import 'package:vnoteapp/components/panel.dart';
import 'controller.dart';

class ServicePackageContractPage
    extends GetView<ServicePackageContractController> {
  const ServicePackageContractPage({super.key});
  static const double labelSize = 20;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: const Color.fromRGBO(238, 238, 238, 1),
      appBar: VAppBar(
        titleWidget: const Text(
          "签约",
          style: TextStyle(fontSize: 24),
        ),
      ),
      endDrawer: _servicePackageDrawer(context),
      body: Builder(builder: (context) {
        return Padding(
          padding: const EdgeInsets.symmetric(horizontal: 200, vertical: 8),
          child: ListView(
            children: [
              Column(
                children: [
                  _buildPhotoVPanel(),
                  const SizedBox(height: 16),
                  _buildContractDoctorVPanel(),
                  const SizedBox(height: 16),
                  _buildPatientVPanel(),
                  const SizedBox(height: 16),
                  _buildServicePackageVPanel(context),
                ],
              ),
            ],
          ),
        );
      }),
    );
  }

  Drawer _servicePackageDrawer(BuildContext context) {
    const double titleSize = 20;
    const double labelSize = 18;
    Widget _buildItem() {
      return Container(
        margin: const EdgeInsets.all(10),
        padding: const EdgeInsets.symmetric(
          vertical: 15,
          horizontal: 15,
        ),
        decoration: BoxDecoration(
          border: Border.all(
            color: Colors.grey.shade400,
          ),
          borderRadius: const BorderRadius.all(
            Radius.circular(4),
          ),
        ),
        child: const Column(
          children: [
            Row(
              children: [
                Expanded(
                    child: Row(
                  children: [
                    Text(
                      '服务包名称：',
                      style: TextStyle(fontSize: titleSize),
                    ),
                    Text(
                      '基础包',
                      style: TextStyle(fontSize: labelSize),
                    ),
                  ],
                )),
                Expanded(
                  child: Row(
                    children: [
                      Text(
                        '服务人群：',
                        style: TextStyle(fontSize: titleSize),
                      ),
                      Text(
                        '老年人等',
                        style: TextStyle(fontSize: labelSize),
                      ),
                    ],
                  ),
                ),
              ],
            ),
            SizedBox(
              height: 10,
            ),
            Row(
              mainAxisSize: MainAxisSize.max,
              children: [
                Expanded(
                  child: Row(
                    mainAxisSize: MainAxisSize.max,
                    children: [
                      Text(
                        '服务包介绍：',
                        style: TextStyle(fontSize: titleSize),
                      ),
                      Expanded(
                        child: Text(
                          '爱神的箭的健康路撒点击可手动就开始啦京东卡拉斯介绍尽快落实的数据库垃圾的大多数的阿达',
                          overflow: TextOverflow.ellipsis,
                          maxLines: 3,
                          style: TextStyle(fontSize: labelSize),
                        ),
                      ),
                    ],
                  ),
                ),
              ],
            ),
          ],
        ),
      );
    }

    return Drawer(
      width: MediaQuery.of(context).size.width * 0.7,
      child: Container(
          margin: const EdgeInsets.all(50),
          child: ListView(
            children: [
              _buildItem(),
              _buildItem(),
              _buildItem(),
              _buildItem(),
              _buildItem(),
              _buildItem(),
              _buildItem(),
              _buildItem(),
            ],
          )),
    );
  }

  Widget _buildPhotoVPanel() {
    return VPanel(
      child: VListFormCellGroup(
        children: [
          VListFormCell(
            label: '拍照',
            height: 70,
            contentWidget: const Center(
              child: Icon(
                Icons.supervised_user_circle_outlined,
                size: 70,
              ),
            ),
            onTap: () {
              print('拍照拍照');
            },
          ),
        ],
      ),
    );
  }

  Widget _buildContractDoctorVPanel() {
    return const VPanel(
      child: VListFormCellGroup(
        children: [
          VListFormCell(
            label: '签约日期',
          ),
          VListFormCell(
            label: '签约医生',
            content: '李四',
          ),
          VListFormCell(
            label: '医生电话',
            content: '18712341234',
          ),
        ],
      ),
    );
  }

  Widget _buildPatientVPanel() {
    return const VPanel(
      child: VListFormCellGroup(
        children: [
          VListFormCell(
            label: '姓名',
            content: '张三',
          ),
          VListFormCell(
            label: '身份证号码',
            content: '5130221999099987',
          ),
          VListFormCell(
            label: '民族',
            content: '汉族',
          ),
          VListFormCell(
            label: '性别',
            content: '男',
          ),
          VListFormCell(
            label: '出生日期',
            content: '张三',
          ),
          VListFormCell(
            label: '联系电话',
            content: '18712341234',
          ),
        ],
      ),
    );
  }

  Widget _buildServicePackageVPanel(BuildContext context) {
    return VPanel(
      child: VListFormCellGroup(
        children: [
          VListFormCell(
            label: '家庭医生服务包',
            height: 70,
            contentWidget: const SizedBox(
              child: Row(
                children: [
                  SizedBox(
                    height: 70,
                  ),
                ],
              ),
            ),
            onTap: () {
              Scaffold.of(context).openEndDrawer();
            },
          ),
          const VListFormCell(
            label: '备注',
            content: '5130221999099987',
          ),
        ],
      ),
    );
  }
}
